@@ -320,11 +320,11 @@ def main():
                            help='place js in external files')
     htmloptions.add_argument('--rfc-base-url', default="https://www.rfc-editor.org/rfc/",
                            help='Base URL for RFC links')
-    htmloptions.add_argument('--id-base-url', default="https://tools.ietf.org/html/",
+    htmloptions.add_argument('--id-base-url', default="https://datatracker.ietf.org/doc/html/",
                            help='Base URL for Internet-Draft links')
     htmloptions.add_argument('--rfc-reference-base-url', default="https://rfc-editor.org/rfc/",
                            help='Base URL for RFC reference targets, replacing the target="..." value given in the reference entry')
-    htmloptions.add_argument('--id-reference-base-url', default="https://tools.ietf.org/html/",
+    htmloptions.add_argument('--id-reference-base-url', default="https://datatracker.ietf.org/doc/html/",
                            help='Base URL for I-D reference targets')
     htmloptions.add_argument('--metadata-js-url', default="metadata.min.js",
                            help='URL for the metadata script')
@@ -693,7 +693,7 @@ def main():
             options.output_filename = None
 
         if options.v2v3:
-            xmlrfc = parser.parse(remove_comments=False, quiet=True, normalize=False, add_xmlns=True)
+            xmlrfc = parser.parse(remove_comments=False, quiet=True, normalize=False, strip_cdata=False, add_xmlns=True)
             filename = options.output_filename
             if not filename:
                 filename = basename + '.v2v3.xml'
